==> nextcloud-app-mail-1.4.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/hu.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Levelezés",
    "Auto detect failed. Please use manual mode." : "Automatikus észlelés sikertelen. Használja a manuális módot.",
    "Updating account failed: " : "Fiók frissítése sikertelen:",
    "Creating account failed: " : "Fiók létrehozása sikertelen: ",
    "Embedded message %s" : "Beágyazott üzenet %s",
    "💌 A mail app for Nextcloud" : "E-mail alkalmazás a Nextcloud-hoz",
    "Auto" : "Automatikus",
    "Name" : "Név",
    "Mail Address" : "E-mail cím",
    "Password" : "Jelszó",
    "Manual" : "Manuális",
    "IMAP Settings" : "IMAP beállítások",
    "IMAP Host" : "IMAP kiszolgáló",
    "IMAP Security" : "IMAP Biztonság",
    "None" : "Semmi",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP felhasználó",
    "IMAP Password" : "IMAP jelszó",
    "SMTP Settings" : "SMTP Beállítások",
    "SMTP Host" : "SMTP kiszolgáló",
    "SMTP Security" : "SMTP biztonság",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP felhasználó",
    "SMTP Password" : "SMTP jelszó",
    "Save" : "Mentés",
    "Connect" : "Csatlakozás",
    "Add mail account" : "E-mail fiók hozzáadás",
    "Use Gravatar and favicon avatars" : "Gravatar és favicon avatarok használata",
    "Register as application for mail links" : "Alkalmazás beállítása e-mail hivatkozásokhoz",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "From" : "Feladó",
    "Select account" : "Fiók kiválasztása",
    "To" : "Címzett",
    "Contact or email address …" : "Címzett vagy e-mail cím ...",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Cc",
    "No contacts found." : "Nem találhatók névjegyek.",
    "Bcc" : "Bcc",
    "Subject" : "Tárgy",
    "Subject …" : "Tárgy ...",
    "Write message …" : "Írj üzenetet ...",
    "Saving draft …" : "Vázlat mentése ...",
    "Draft saved" : "Vázlat elmentve",
    "Upload attachment" : "Csatolmány feltöltése",
    "Add attachment from Files" : "Csatolmány hozzáadása a Fájlok közül",
    "Add attachment link from Files" : "Csatolmány hivatkozás hozzáadása a Fájlok közül",
    "Enable formatting" : "Formázás engedélyezése",
    "Uploading attachments …" : "Csatolmányok feltöltése ...",
    "Sending …" : "Küldés...",
    "Error sending your message" : "Hiba az üzeneted elküldésekor",
    "Go back" : "Visszalép",
    "Retry" : "Újra",
    "Message sent!" : "Üzenet elküldve!",
    "Write another message" : "Új üzenet írása",
    "Send" : "Küldés",
    "Uploading {percent}% …" : "Feltöltés {percent}% …",
    "Choose a file to add as attachment" : "Csatolandó fájl kiválasztása",
    "Choose a file to share as a link" : "Fájl kiválasztása hivatkozás alapú megosztáshoz",
    "Writing mode" : "Írási mód",
    "Plain text" : "Egyszerű szöveg",
    "Rich text" : "Rich formátum",
    "No messages in this folder" : "Nincs üzenet a mappában!",
    "No messages" : "Nincs üzenet",
    "Draft: " : "Vázlat:",
    "Unfavorite" : "Nem kedvenc",
    "Favorite" : "Kedvenc",
    "Mark important" : "Fontosnak jelöl",
    "Mark unread" : "Olvasatlannak jelöl",
    "Mark read" : "Olvasottnak jelöl",
    "Unselect" : "Kiválasztás megszüntetése",
    "Select" : "Kijelölés",
    "Delete" : "Törlés",
    "Report this bug" : "A hiba bejelentése",
    "Could not open mailbox" : "Mailbox nem nyitható meg",
    "Loading messages" : "Üzenetek betöltése",
    "Important" : "Fontos",
    "Favorites" : "Kedvencek",
    "Other" : "Egyéb",
    "Not found" : "Nem található",
    "to" : "címzett",
    "cc" : "másolat",
    "Reply" : "Válasz",
    "Reply to sender only" : "Válasz csak a feladónak",
    "Forward" : "Tovább",
    "View source" : "Forrás megtekintése",
    "Message source" : "Üzenet forrása",
    "Could not load your message" : "Nem lehet betölteni az üzenetedet",
    "Import into calendar" : "Betöltés a naptárba",
    "Download attachment" : "Melléklet letöltése",
    "Save to Files" : "Metés a Fájlokba",
    "Unnamed" : "Névtelen",
    "Embedded message" : "Beágyazott üzenet",
    "Choose a folder to store the attachment in" : "Válasszon egy mappát a mellékletek tárolásához:",
    "Save all to Files" : "Minden mentése a Fájlokba",
    "Choose a folder to store the attachments in" : "Válasszon egy mappát a mellékletek tárolásához",
    "The images have been blocked to protect your privacy." : "A személyes adataid védelme érdekében a képeket letiltottuk.",
    "Show images from this sender" : "Képek megjelenítése ettől a feladótól",
    "New message" : "Új üzenet",
    "Settings" : "Beállítások",
    "Quota" : "Kvóta",
    "Edit account" : "Fiók szerkesztése",
    "Add folder" : "Mappa hozzáadás",
    "Move Up" : "Mozgatás Fel",
    "Move down" : "Mozgatás Le",
    "Remove account" : "Fiók eltávolítása",
    "Loading …" : "Töltés ...",
    "Remove account {email}" : "Fiók eltávolítása {email}",
    "Remove {email}" : "Eltávolítás {email}",
    "Cancel" : "Mégse",
    "Show all folders" : "Minden mappa megjelenítése",
    "Collapse folders" : "Mappák összecsukása",
    "Mark all as read" : "Az összes megjelölése olvasottként",
    "Mark all messages of this folder as read" : "A mappában található összes üzenet megjelölése olvasottként",
    "Add subfolder" : "Almappa hozzáadás",
    "Clear cache" : "Gyorsítótár ürítése",
    "Could not load your draft" : "Nem lehet betölteni a vázlatot",
    "Could not load original message" : "Nem lehet betölteni az eredeti üzenetet",
    "No message selected" : "Nincs kiválasztott üzenet",
    "Signature" : "Aláírás",
    "Signature …" : "Aláírás ...",
    "Save signature" : "Aláírás mentése",
    "Import into {calendar}" : "Betöltés ide: {calendar}",
    "Airplane" : "Repülő",
    "Train" : "Vonat",
    "Mail app" : "Levelező alkalmazás",
    "Email: {email}" : "E-mail: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} itt {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} itt {host}:{port} ({ssl} encryption)",
    "General" : "Általános",
    "Email address" : "E-mail cím",
    "IMAP" : "IMAP",
    "User" : "Felhasználó",
    "Host" : "Kiszolgáló",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Account settings" : "Fiók beállítások",
    "Change name" : "Név megváltoztatása",
    "Mail server" : "Levelezőszerver",
    "Speed up your Mail experience with these quick shortcuts." : "Gyorsítsd fel a levelezési élményedet ezekkel a rövidítésekkel.",
    "Compose new message" : "Új üzenet írása",
    "Newer message" : "Újabb üzenet",
    "Older message" : "Régebbi üzenet",
    "Toggle star" : "Csillagozás váltása",
    "Toggle unread" : "Olvasatlanság váltása",
    "Search" : "Keresés",
    "Refresh" : "Frissítés",
    "Connect your mail account" : "Kapcsolódás az e-mail fiókodhoz",
    "All" : "Mind",
    "Archive" : "Archívum",
    "Drafts" : "Vázlatok",
    "All inboxes" : "Minden bejövő",
    "Inbox" : "Bejövő",
    "Junk" : "Szemét",
    "Sent" : "Elküldött",
    "Trash" : "Lomtár",
    "Error while sharing file" : "Hiba a fájl megosztása közben",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n új üzenet \nfeladó: {from}","%n új üzenet \nfeladó: {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Nem tölthető be: {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Probléma volt a betöltéssel: {tag}{name}{endtag}",
    "Could not load the desired message" : "Nem lehet betölteni a kért üzenetet",
    "Could not load the message" : "Nem lehet betölteni az üzenetet",
    "Error loading message" : "Hiba történt az üzenet betöltése közben",
    "Forwarding to %s" : "Továbbítás ide: %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kattints ide, ha a következő néhány másodpercben lennél automatikusan átirányítva.",
    "Redirect" : "Átirányítás",
    "The link leads to %s" : "A hivatkozás ide mutat: %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarod megnyitni azt az oldalt, akkor térj vissza a <a href=\"%s\">Levelekhez</a>",
    "Continue to %s" : "Folytatás ide: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/hu.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Automatikus észlelés sikertelen. Használja a manuális módot.",
    "Updating account failed: " : "Fiók frissítése sikertelen:",
    "Creating account failed: " : "Fiók létrehozása sikertelen: ",
    "Embedded message %s" : "Beágyazott üzenet %s",
    "Mails" : "Levelek",
    "Mail" : "Levelezés",
    "💌 A mail app for Nextcloud" : "E-mail alkalmazás a Nextcloud-hoz",
    "Auto" : "Automatikus",
    "Name" : "Név",
    "Mail Address" : "E-mail cím",
    "Password" : "Jelszó",
    "Manual" : "Manuális",
    "IMAP Settings" : "IMAP beállítások",
    "IMAP Host" : "IMAP kiszolgáló",
    "IMAP Security" : "IMAP Biztonság",
    "None" : "Semmi",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP port",
    "IMAP User" : "IMAP felhasználó",
    "IMAP Password" : "IMAP jelszó",
    "SMTP Settings" : "SMTP Beállítások",
    "SMTP Host" : "SMTP kiszolgáló",
    "SMTP Security" : "SMTP biztonság",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP felhasználó",
    "SMTP Password" : "SMTP jelszó",
    "Save" : "Mentés",
    "Connect" : "Csatlakozás",
    "Add mail account" : "E-mail fiók hozzáadás",
    "Use Gravatar and favicon avatars" : "Gravatar és favicon avatarok használata",
    "Register as application for mail links" : "Alkalmazás beállítása e-mail hivatkozásokhoz",
    "Show keyboard shortcuts" : "Billentyűparancsok mutatása",
    "From" : "Feladó",
    "Select account" : "Fiók kiválasztása",
    "To" : "Címzett",
    "Contact or email address …" : "Címzett vagy e-mail cím ...",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Cc",
    "No contacts found." : "Nem találhatók névjegyek.",
    "Bcc" : "Bcc",
    "Subject" : "Tárgy",
    "Subject …" : "Tárgy ...",
    "Write message …" : "Írj üzenetet ...",
    "Saving draft …" : "Vázlat mentése ...",
    "Draft saved" : "Vázlat elmentve",
    "Upload attachment" : "Csatolmány feltöltése",
    "Add attachment from Files" : "Csatolmány hozzáadása a Fájlok közül",
    "Add attachment link from Files" : "Csatolmány hivatkozás hozzáadása a Fájlok közül",
    "Enable formatting" : "Formázás engedélyezése",
    "Uploading attachments …" : "Csatolmányok feltöltése ...",
    "Sending …" : "Küldés...",
    "Error sending your message" : "Hiba az üzeneted elküldésekor",
    "Go back" : "Visszalép",
    "Retry" : "Újra",
    "Message sent!" : "Üzenet elküldve!",
    "Write another message" : "Új üzenet írása",
    "Send" : "Küldés",
    "Uploading {percent}% …" : "Feltöltés {percent}% …",
    "Choose a file to add as attachment" : "Csatolandó fájl kiválasztása",
    "Choose a file to share as a link" : "Fájl kiválasztása hivatkozás alapú megosztáshoz",
    "Writing mode" : "Írási mód",
    "Plain text" : "Egyszerű szöveg",
    "Rich text" : "Rich formátum",
    "No messages in this folder" : "Nincs üzenet a mappában!",
    "No messages" : "Nincs üzenet",
    "Draft: " : "Vázlat:",
    "Mark important" : "Fontosnak jelöl",
    "Mark unread" : "Olvasatlannak jelöl",
    "Mark read" : "Olvasottnak jelöl",
    "Unselect" : "Kiválasztás megszüntetése",
    "Select" : "Kijelölés",
    "Delete" : "Törlés",
    "Report this bug" : "A hiba bejelentése",
    "Could not open mailbox" : "Mailbox nem nyitható meg",
    "Loading messages" : "Üzenetek betöltése",
    "Important" : "Fontos",
    "Favorites" : "Kedvencek",
    "Other" : "Egyéb",
    "Attachments" : "Mellékletek",
    "Import into calendar" : "Betöltés a naptárba",
    "Download attachment" : "Melléklet letöltése",
    "Save to Files" : "Metés a Fájlokba",
    "Unnamed" : "Névtelen",
    "Embedded message" : "Beágyazott üzenet",
    "Choose a folder to store the attachment in" : "Válasszon egy mappát a mellékletek tárolásához:",
    "Save all to Files" : "Minden mentése a Fájlokba",
    "Choose a folder to store the attachments in" : "Válasszon egy mappát a mellékletek tárolásához",
    "The images have been blocked to protect your privacy." : "A személyes adataid védelme érdekében a képeket letiltottuk.",
    "Show images from this sender" : "Képek megjelenítése ettől a feladótól",
    "New message" : "Új üzenet",
    "Settings" : "Beállítások",
    "Quota" : "Kvóta",
    "Account settings" : "Fiók beállítások",
    "Add folder" : "Mappa hozzáadás",
    "Saving" : "Mentés",
    "Move down" : "Mozgatás Le",
    "Remove account" : "Fiók eltávolítása",
    "Loading …" : "Töltés ...",
    "Remove account {email}" : "Fiók eltávolítása {email}",
    "Remove {email}" : "Eltávolítás {email}",
    "Cancel" : "Mégse",
    "Show all folders" : "Minden mappa megjelenítése",
    "Collapse folders" : "Mappák összecsukása",
    "Mark all as read" : "Az összes megjelölése olvasottként",
    "Add subfolder" : "Almappa hozzáadás",
    "Edit name" : "Név szerkesztése",
    "Clear cache" : "Gyorsítótár ürítése",
    "Delete folder" : "Mappa törlés",
    "Not found" : "Nem található",
    "Could not load your draft" : "Nem lehet betölteni a vázlatot",
    "Could not load original message" : "Nem lehet betölteni az eredeti üzenetet",
    "No message selected" : "Nincs kiválasztott üzenet",
    "Signature" : "Aláírás",
    "Signature …" : "Aláírás ...",
    "Save signature" : "Aláírás mentése",
    "Reply" : "Válasz",
    "Reply to sender only" : "Válasz csak a feladónak",
    "Forward" : "Tovább",
    "View source" : "Forrás megtekintése",
    "Message source" : "Üzenet forrása",
    "Import into {calendar}" : "Betöltés ide: {calendar}",
    "Airplane" : "Repülő",
    "Train" : "Vonat",
    "Mail app" : "Levelező alkalmazás",
    "Email: {email}" : "E-mail: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} itt {host}:{port} ({ssl} encryption)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} itt {host}:{port} ({ssl} encryption)",
    "General" : "Általános",
    "Email address" : "E-mail cím",
    "IMAP" : "IMAP",
    "User" : "Felhasználó",
    "Host" : "Kiszolgáló",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Change name" : "Név megváltoztatása",
    "Mail server" : "Levelezőszerver",
    "Keyboard shortcut" : "Billyentyűparancs",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "Speed up your Mail experience with these quick shortcuts." : "Gyorsítsd fel a levelezési élményedet ezekkel a rövidítésekkel.",
    "Compose new message" : "Új üzenet írása",
    "Newer message" : "Újabb üzenet",
    "Older message" : "Régebbi üzenet",
    "Toggle star" : "Csillagozás váltása",
    "Toggle unread" : "Olvasatlanság váltása",
    "Search" : "Keresés",
    "Refresh" : "Frissítés",
    "Connect your mail account" : "Kapcsolódás az e-mail fiókodhoz",
    "All" : "Mind",
    "Archive" : "Archívum",
    "Drafts" : "Vázlatok",
    "All inboxes" : "Minden bejövő",
    "Inbox" : "Bejövő",
    "Junk" : "Szemét",
    "Sent" : "Elküldött",
    "Trash" : "Lomtár",
    "Error while sharing file" : "Hiba a fájl megosztása közben",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n új üzenet \nfeladó: {from}","%n új üzenet \nfeladó: {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Could not load {tag}{name}{endtag}" : "Nem tölthető be: {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Probléma volt a betöltéssel: {tag}{name}{endtag}",
    "Could not load your message" : "Nem lehet betölteni az üzenetedet",
    "Could not load the desired message" : "Nem lehet betölteni a kért üzenetet",
    "Could not load the message" : "Nem lehet betölteni az üzenetet",
    "Error loading message" : "Hiba történt az üzenet betöltése közben",
    "Forwarding to %s" : "Továbbítás ide: %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kattints ide, ha a következő néhány másodpercben lennél automatikusan átirányítva.",
    "Redirect" : "Átirányítás",
    "The link leads to %s" : "A hivatkozás ide mutat: %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarod megnyitni azt az oldalt, akkor térj vissza a <a href=\"%s\">Levelekhez</a>",
    "Continue to %s" : "Folytatás ide: %s"
},
"nplurals=2; plural=(n != 1);");
